Module process_isolation

Module process_isolation 

Process isolation for VST3 plugin hosting

This module provides functionality to run VST3 plugins in separate processes for improved stability and crash protection.

Modules

crash_protection
Crash protection utilities for in-process plugins

Structs

PluginHostProcess
Manages a plugin running in an isolated process.
ProtocolChannel
The helper process’s write half of the request/response protocol.

Enums

HostCommand
Commands that can be sent to the isolated plugin process.
HostResponse
Responses from the isolated plugin process
IsolationError
Errors that can occur during process isolation

Type Aliases

IsolationResult
Result type for process isolation operations