Process isolation for VST3 plugin hosting
This module provides functionality to run VST3 plugins in separate processes for improved stability and crash protection.
Modules
- crash_
protection - Crash protection utilities for in-process plugins
Structs
- Plugin
Host Process - Manages a plugin running in an isolated process.
- Protocol
Channel - The helper process’s write half of the request/response protocol.
Enums
- Host
Command - Commands that can be sent to the isolated plugin process.
- Host
Response - Responses from the isolated plugin process
- Isolation
Error - Errors that can occur during process isolation
Type Aliases
- Isolation
Result - Result type for process isolation operations